@@ -5,8 +5,7 @@ from .genericcollection import GenericCollectionTabularInline
 from .settings import RELATION_MODELS, JAVASCRIPT_URL, REGISTER_ADMIN
 from .models import Category
 from .base import CategoryBaseAdminForm, CategoryBaseAdmin
-
-from categories import model_registry
+from .settings import MODEL_REGISTRY
 
 
 class NullTreeNodeChoiceField(forms.ModelChoiceField):
@@ -32,7 +31,7 @@ if RELATION_MODELS:
 class CategoryAdminForm(CategoryBaseAdminForm):
     class Meta:
         model = Category
-    
+
     def clean_alternate_title(self):
         if self.instance is None or not self.cleaned_data['alternate_title']:
             return self.cleaned_data['name']
@@ -48,7 +47,7 @@ class CategoryAdmin(CategoryBaseAdmin):
             'fields': ('parent', 'name', 'thumbnail', 'active')
         }),
         ('Meta Data', {
-            'fields': ('alternate_title', 'alternate_url', 'description', 
+            'fields': ('alternate_title', 'alternate_url', 'description',
                         'meta_keywords', 'meta_extra'),
             'classes': ('collapse',),
         }),
@@ -57,10 +56,10 @@ class CategoryAdmin(CategoryBaseAdmin):
             'classes': ('collapse',),
         }),
     )
-    
+
     if RELATION_MODELS:
-        inlines = [InlineCategoryRelation,]
-    
+        inlines = [InlineCategoryRelation, ]
+
     class Media:
         js = (JAVASCRIPT_URL + 'genericcollections.js',)
 
@@ -68,9 +67,9 @@ if REGISTER_ADMIN:
     admin.site.register(Category, CategoryAdmin)
 
 for model, modeladmin in admin.site._registry.items():
-    if model in model_registry.values() and modeladmin.fieldsets:
+    if model in MODEL_REGISTRY.values() and modeladmin.fieldsets:
         fieldsets = getattr(modeladmin, 'fieldsets', ())
-        fields = [cat.split('.')[2] for cat in model_registry if model_registry[cat] == model]
+        fields = [cat.split('.')[2] for cat in MODEL_REGISTRY if MODEL_REGISTRY[cat] == model]
         # check each field to see if already defined
         for cat in fields:
             for k, v in fieldsets:
